import type { RegistryScriptInput } from '#nuxt-scripts';
/**
 * Sample:
 * <!-- Cloudflare Web Analytics -->
 * <script defer src='https://static.cloudflareinsights.com/beacon.min.js' data-cf-beacon='{"token": "12ee46bf598b45c2868bbc07a3073f58"}'></script>
 * <!-- End Cloudflare Web Analytics -->
 */
export interface CloudflareWebAnalyticsApi {
    __cfBeacon: {
        load: 'single';
        spa: boolean;
        token: string;
    };
}
declare global {
    interface Window extends CloudflareWebAnalyticsApi {
    }
}
export declare const CloudflareWebAnalyticsOptions: import("valibot").ObjectSchema<{
    /**
     * The Cloudflare Web Analytics token.
     */
    token: import("valibot").StringSchema<string>;
    /**
     * Cloudflare Web Analytics enables measuring SPAs automatically by overriding the History API’s pushState function
     * and listening to the onpopstate. Hash-based router is not supported.
     *
     * @default true
     */
    spa: import("valibot").OptionalSchema<import("valibot").BooleanSchema<boolean>, undefined, boolean | undefined>;
}, undefined, {
    token: string;
    spa?: boolean | undefined;
}>;
export type CloudflareWebAnalyticsInput = RegistryScriptInput<typeof CloudflareWebAnalyticsOptions>;
export declare function useScriptCloudflareWebAnalytics<T extends CloudflareWebAnalyticsApi>(_options?: CloudflareWebAnalyticsInput): T & {
    $script: Promise<T> & import("@unhead/vue").VueScriptInstance<T>;
};
